@@ -1,5 +1,26 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+##################################################################################
+##    PSFreedom UI for the N900, UI to easily jailbreak the PS3                 ##
+##    Copyright (C) 2010 Mohammad Abu-Garbeyyeh                                 ##
+##                  2010 Youness Alaoui (modules used in the application)       ##
+##                  2010 Mobashir Ahmed (Graphics used in application)          ##
+##                                                                              ##
+##    This program is free software; you can redistribute it and/or modify      ##
+##    it under the terms of the GNU General Public License as published by      ##
+##    the Free Software Foundation; either version 2 of the License, or         ##
+##    (at your option) any later version.                                       ##
+##                                                                              ##
+##    This program is distributed in the hope that it will be useful,           ##
+##    but WITHOUT ANY WARRANTY; without even the implied warranty of            ##
+##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             ##
+##    GNU General Public License for more details.                              ##
+##                                                                              ##
+##    You should have received a copy of the GNU General Public License         ##
+##    along with this program; if not, write to the Free Software               ##
+##    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA ##
+##################################################################################
+
 print "Importing PyQt4 modules"
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import *
@@ -73,12 +94,22 @@ class MainWindow(QtGui.QMainWindow):
 	MainWindow.labeldisabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
 	MainWindow.labeldisabled.setObjectName("label")
 	MainWindow.labeldisabled.setText(QtGui.QApplication.translate("MainWindow", "PSFreedom status: Disabled", None, QtGui.QApplication.UnicodeUTF8))
-	MainWindow.labeldisabled.show()
+	MainWindow.labeldisabled.hide()
 	MainWindow.labelenabled = QtGui.QLabel(self)
 	MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
 	MainWindow.labelenabled.setObjectName("label")
 	MainWindow.labelenabled.setText(QtGui.QApplication.translate("MainWindow", "PSFreedom status: Enabled", None, QtGui.QApplication.UnicodeUTF8))
         MainWindow.labelenabled.hide()
+	MainWindow.labelbdemudisabled = QtGui.QLabel(self)
+	MainWindow.labelbdemudisabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
+	MainWindow.labelbdemudisabled.setObjectName("label")
+	MainWindow.labelbdemudisabled.setText(QtGui.QApplication.translate("MainWindow", "BD Emulation disabled", None, QtGui.QApplication.UnicodeUTF8))
+	MainWindow.labelbdemuenabled = QtGui.QLabel(self)
+	MainWindow.labelbdemuenabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
+	MainWindow.labelbdemuenabled.setObjectName("label")
+	MainWindow.labelbdemuenabled.setText(QtGui.QApplication.translate("MainWindow", "BD Emulation enabled", None, QtGui.QApplication.UnicodeUTF8))
+	MainWindow.labelbdemudisabled.hide()
+	MainWindow.labelbdemuenabled.hide()
 	# Buttons
         self.button1 = QtGui.QPushButton("Jailbreak mode on", self)
         self.button1.setObjectName("button1")
@@ -88,19 +119,84 @@ class MainWindow(QtGui.QMainWindow):
         self.button2.setObjectName("button2")
 	self.button2.setGeometry(QtCore.QRect(200, 220, 447, 70))
 	self.button2.hide()
+	MainWindow.button3 = QtGui.QPushButton("Enable BD emu", self)
+	MainWindow.button3.setGeometry(QtCore.QRect(290, 300, 247, 50))
+	MainWindow.button3.hide()
+	MainWindow.button4 = QtGui.QPushButton("Disable BD emu", self)
+	MainWindow.button4.setGeometry(QtCore.QRect(290, 300, 247, 50))
+	MainWindow.button4.hide()
+	self.checkmodulestatus()
+#	self.payload_list = QtGui.QComboBox(self)
+#	self.payload_list.setGeometry(QtCore.QRect(300, 320, 190, 45))
+#	self.payload_list.addItem("payload_bdemu.bin")
+#	self.payload_list.addItem("payload_no_bdemu.bin")
+
         self.layout = QtGui.QVBoxLayout()
         self.setLayout(self.layout)
 
 	# Connecting buttons and menu items.
 	QtCore.QObject.connect(self.button1, QtCore.SIGNAL("clicked()"), self.jailbreakon)
 	QtCore.QObject.connect(self.button2, QtCore.SIGNAL("clicked()"), self.jailbreakoff)
-        QtCore.QObject.connect(self.aboutAction, QtCore.SIGNAL("triggered()"), self.about)
-        QtCore.QObject.connect(self.aboutQtAction, QtCore.SIGNAL("triggered()"), self.aboutQt)
-        QtCore.QObject.connect(self.showLogs, QtCore.SIGNAL("triggered()"), self.logs)
+	QtCore.QObject.connect(self.button3, QtCore.SIGNAL("clicked()"), self.enablebdemu)
+	QtCore.QObject.connect(self.button4, QtCore.SIGNAL("clicked()"), self.disablebdemu)
+	QtCore.QObject.connect(self.aboutAction, QtCore.SIGNAL("triggered()"), self.about)
+	QtCore.QObject.connect(self.aboutQtAction, QtCore.SIGNAL("triggered()"), self.aboutQt)
+	QtCore.QObject.connect(self.showLogs, QtCore.SIGNAL("triggered()"), self.logs)
 	QtCore.QObject.connect(self.help, QtCore.SIGNAL("triggered()"), self.helpafterrun)
-#        QtCore.QObject.connect(self.portrait, QtCore.SIGNAL("triggered()"), self.portraitmode)
+#      QtCore.QObject.connect(self.portrait, QtCore.SIGNAL("triggered()"), self.portraitmode)
 
-#   Portrait mode, experimental at the moment, disabled in the GUI at the moment.
+    def enablebdemu(self):
+	MainWindow.button3.hide()
+	MainWindow.button4.show()
+	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --enablebdemu")
+	MainWindow.labelbdemudisabled.hide()
+	MainWindow.labelbdemuenabled.show()
+	bus = dbus.SystemBus()
+        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
+                                              '/org/freedesktop/Notifications'),
+                                              'org.freedesktop.Notifications')
+        iface.SystemNoteInfoprint("BD Emulation enabled.")
+
+    def disablebdemu(self):
+	MainWindow.button3.show()
+	MainWindow.button4.hide()
+	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --disablebdemu")
+	MainWindow.labelbdemuenabled.hide()
+	MainWindow.labelbdemudisabled.show()
+	bus = dbus.SystemBus()
+        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
+                                              '/org/freedesktop/Notifications'),
+                                              'org.freedesktop.Notifications')
+        iface.SystemNoteInfoprint("BD Emulation disabled.")
+
+
+    def checkmodulestatus(self):
+	if os.path.isfile("/proc/psfreedom/status"):
+		self.button1.hide()
+		self.button2.show()
+		MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 365, 391, 20))
+		MainWindow.labelenabled.show()
+		MainWindow.labeldisabled.hide()
+		payload = os.popen("cat /proc/psfreedom/payload | grep dev").read()
+		payloadstripped = str(payload).strip()
+		if str(payloadstripped) == "/dev_bdvd":
+			MainWindow.button4.show()
+			MainWindow.button3.hide()
+			MainWindow.labelbdemudisabled.hide()
+			MainWindow.labelbdemuenabled.show()
+		else:
+			MainWindow.button4.hide()
+			MainWindow.button3.show()
+			MainWindow.labelbdemuenabled.hide()
+			MainWindow.labelbdemudisabled.show()
+	else:
+		self.button1.show()
+		self.button2.hide()
+		MainWindow.labelenabled.hide()
+		MainWindow.labeldisabled.show()
+		
+
+#   Portrait mode, experimental, disabled in the GUI at the moment.
     def portraitmode(self):
         self.resize(480, 800)
         self.setAttribute(Qt.WA_Maemo5PortraitOrientation)
@@ -112,7 +208,7 @@ class MainWindow(QtGui.QMainWindow):
         res = 480, 800
 #	MainWindow.labeldisabled.setGeometry(QtCore.QRect(0, 750, 391, 20))       
 
-#   Check if first run, if yes, show dialog with steps needed to jailbreak, if not, do nothing
+#   Check if first run, if yes, show help window with steps needed to jailbreak, if not, do nothing
     def firstrun(self):
 	if os.path.isfile("/home/user/.psfreedom_ran"):
 		print "PSFreedom started before, not auto-popping up help dialog"
@@ -324,12 +420,12 @@ class MainWindow(QtGui.QMainWindow):
 #	aboutWin.textBrowser.show()
 # =========================================================================================================================
 	web = QWebView(aboutWin)
+	web.load(QUrl("file:///opt/psfreedom/resources/aboutpsfreedom.html"))
+	web.setGeometry(QtCore.QRect(0, 0, 800, 460))
         suppressor = QWebViewSelectionSuppressor(web)
         suppressor.enable()
         scroller = web.property("kineticScroller").toPyObject()
         scroller.setEnabled(True)
-	web.load(QUrl("file:///opt/psfreedom/resources/aboutpsfreedom.html"))
-	web.setGeometry(QtCore.QRect(0, 0, 800, 460))
 	web.show()
 
 #   Jailbreak on button function
@@ -344,6 +440,9 @@ class MainWindow(QtGui.QMainWindow):
                                               '/org/freedesktop/Notifications'),
                                               'org.freedesktop.Notifications')
         iface.SystemNoteInfoprint("Jailbreak mode enabled")
+	MainWindow.button3.show()
+	MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 365, 391, 20))
+	MainWindow.labelbdemudisabled.show()
 	self.firstrun()
 
 #   Jailbreak off button function
@@ -353,11 +452,17 @@ class MainWindow(QtGui.QMainWindow):
 	self.button1.show()
 	MainWindow.labelenabled.hide()
 	MainWindow.labeldisabled.show()
+	self.disablebdemu()
         bus = dbus.SystemBus()
         iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                               '/org/freedesktop/Notifications'),
                                               'org.freedesktop.Notifications')
         iface.SystemNoteInfoprint("Jailbreak mode disabled")
+	MainWindow.button3.hide()
+	MainWindow.button4.hide()
+	MainWindow.labelbdemudisabled.hide()
+	MainWindow.labelbdemuenabled.hide()
+
 
 # Starting up the app
 if __name__ == "__main__":
